@@ -145,7 +145,7 @@ function(lm.out, nm, mydata, my.formula, brief, res.rows,
        x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
        fit.line="none", col.fit.line="grey55", center.line=NULL,
        col.bubble=NULL, bubble.size=.25, col.flower=NULL,
-       ellipse=FALSE, col.ellipse="lightslategray", fill.ellipse=TRUE,
+       ellipse=FALSE, 
        diag=FALSE, col.diag=par("fg"), lines.diag=TRUE,
        quiet=TRUE, ylim=c(0,1))
 
