@@ -1,6 +1,6 @@
 .reg5Plot <-
 function(lm.out, res.rows=NULL, pred.rows=NULL,
-         scatter.coef=FALSE, scatter.3D=FALSE, X1.new=NULL,
+         scatter.coef=FALSE, X1.new=NULL,
          numeric.all, in.data.frame, c.int, p.int,
          pdf=FALSE, pdf.width=5, pdf.height=5, manage.gr=FALSE, ...) {
 
@@ -77,7 +77,7 @@ function(lm.out, res.rows=NULL, pred.rows=NULL,
        x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
        fit.line=fl, col.fit.line="grey55", center.line=NULL,
        col.bubble=NULL, bubble.size=.25, col.flower=NULL,
-       ellipse=FALSE, col.ellipse="lightslategray", fill.ellipse=TRUE,
+       ellipse=FALSE, 
        diag=FALSE, col.diag=par("fg"), lines.diag=TRUE,
        quiet=TRUE, ylim=c(y.min,y.max))
 
@@ -151,28 +151,33 @@ function(lm.out, res.rows=NULL, pred.rows=NULL,
     cat("\n\n")
   }
 
-  if (scatter.3D) {  # 3d scatterplot option for 2-predictor models
-    if (is.numeric(lm.out$model[,nm[2]]) && is.numeric(lm.out$model[,nm[3]]))
-       proceed.3d <- TRUE
-    else {
-      proceed.3d <- FALSE
-      cat("\n>>> No 3D scatterplot because both predictor variables must be numeric.\n")
-    }
-    if (proceed.3d) { 
+  #if (scatter.3D) {  # 3d scatterplot option for 2-predictor models
+    #cat("\n"); stop(call.=FALSE, "\n","------\n",
+      #"scatter.3D option disabled, car package no longer included\n",
+      #"because of dependencies issues.\n\n",
+      #"If interested, use the scatter3d function from car.\n\n")
+
+    #if (is.numeric(lm.out$model[,nm[2]]) && is.numeric(lm.out$model[,nm[3]]))
+       #proceed.3d <- TRUE
+    #else {
+      #proceed.3d <- FALSE
+      #cat("\n>>> No 3D scatterplot because both predictor variables must be numeric.\n")
+    #}
+    #if (proceed.3d) { 
       #check.rgl <- require(rgl, quietly=TRUE)
-      cat("\n\n\n",
-          "Directions for 3D scatterplot from the car package\n",
-          "--------------------------------------------------\n\n",
-          ">>> The 3D scatter plot requires package rgl.", "\n",
-          ">>> To get the rgl package, run one time only: install.packages(\"rgl\")", "\n\n",
-          "1. Can re-size the plot window, click and drag to rotate plot.\n",
-          "2. Press the right mouse button and drag a rectangle around any points to be\n",
-          "   identified, and then release. Repeat for each set of points to be identified.\n",
-          "3. To exit, right-click in a blank area of the 3d-scatterplot.\n", sep="")
-      suppressMessages(scatter3d(lm.out$terms, id.method="identify", data=lm.out$model))  # car
-      cat("\n")
-    }
-  }
+      #cat("\n\n\n",
+          #"Directions for 3D scatterplot from the car package\n",
+          #"--------------------------------------------------\n\n",
+          #">>> The 3D scatter plot requires package rgl.", "\n",
+          #">>> To get the rgl package, run one time only: install.packages(\"rgl\")", "\n\n",
+          #"1. Can re-size the plot window, click and drag to rotate plot.\n",
+          #"2. Press the right mouse button and drag a rectangle around any points to be\n",
+          #"   identified, and then release. Repeat for each set of points to be identified.\n",
+          #"3. To exit, right-click in a blank area of the 3d-scatterplot.\n", sep="")
+      #suppressMessages(scatter3d(lm.out$terms, id.method="identify", data=lm.out$model))  # car
+      #cat("\n")
+    #}
+  #}
 
   # just generated plot
   invisible(list(i=plt.i, ttl=plt.title))
